import { csv } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl =
  'https://gist.githubusercontent.com/SirishaManthena/143d8a4e801946f7437aec508d8f5254/raw/c138d08f102c2b8c7d61957ef9dba2d25e37cf42/nutritionalinfo.csv';

const parseRow = (d) => {
  return {
    Item: d.Item,
    'Total Fat': +d['Total Fat'],
    Protein: +d.Protein,
    Carbohydrates: +d.Carbohydrates,
  };
};

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const topItems = [
    'Egg McMuffin',
    'Big Mac',
    'Hamburger',
    'Cheeseburger',
    'Double Cheeseburger',
    'McChicken',
    'Chicken McNuggets (10 piece)',
    'Filet-O-Fish',
    'Large French Fries',
    'Hot Fudge Sundae',
  ];

  // Filter data for top items
  const filteredData = data.filter((d) =>
    topItems.includes(d.Item),
  );

  const width = 800;
  const height = 600;

  const plot = scatterPlot()
    .width(width)
    .height(height)
    .margin({ top: 50, right: 50, bottom: 50, left: 50 })
    .data(filteredData)
    .xValue((d) => d['Total Fat'])
    .yValue((d) => d.Protein)
    .zValue((d) => d.Carbohydrates)
    .xLabel('Total Fat')
    .yLabel('Protein')
    .zLabel('Carbohydrates');

  d3.select('.chart-container').call(plot);
};

main();
