export const scatterPlot = () => {
  let width = 800;
  let height = 600;
  let margin = { top: 50, right: 50, bottom: 50, left: 50 };
  let data = [];
  let xValue;
  let yValue;
  let zValue;
  let xLabel = 'Total Fat';
  let yLabel = 'Protein';
  let zLabel = 'Carbohydrates';

  const chart = (selection) => {
    selection.each(function () {
      const svg = d3
        .select(this)
        .attr('width', width)
        .attr('height', height);

      const innerWidth = width - margin.left - margin.right;
      const innerHeight =
        height - margin.top - margin.bottom;

      const xScale = d3
        .scaleLinear()
        .domain(d3.extent(data, xValue))
        .range([0, innerWidth])
        .nice();

      const yScale = d3
        .scaleLinear()
        .domain(d3.extent(data, yValue))
        .range([innerHeight, 0])
        .nice();

      const zScale = d3
        .scaleLinear()
        .domain(d3.extent(data, zValue))
        .range([2, 10]);

      const g = svg
        .append('g')
        .attr(
          'transform',
          `translate(${margin.left},${margin.top})`,
        );

      // X-axis
      const xAxis = d3
        .axisBottom(xScale)
        .tickSize(-innerHeight)
        .tickPadding(10);

      g.append('g')
        .call(xAxis)
        .attr('transform', `translate(0,${innerHeight})`)
        .selectAll('.tick line')
        .attr('stroke', '#C0C0C0');

      // Y-axis
      const yAxis = d3
        .axisLeft(yScale)
        .tickSize(-innerWidth)
        .tickPadding(10);

      g.append('g')
        .call(yAxis)
        .selectAll('.tick line')
        .attr('stroke', '#C0C0C0');

      // Data points
      g.selectAll('.dot')
        .data(data)
        .enter()
        .append('circle')
        .attr('class', 'dot')
        .attr('cx', (d) => xScale(xValue(d)))
        .attr('cy', (d) => yScale(yValue(d)))
        .attr('r', (d) => zScale(zValue(d)))
        .style('fill', 'steelblue');

      // X-axis label
      g.append('text')
        .attr('class', 'axis-label')
        .attr('x', innerWidth / 2)
        .attr('y', innerHeight + margin.bottom - 5)
        .style('text-anchor', 'middle')
        .text(xLabel);

      // Y-axis label
      g.append('text')
        .attr('class', 'axis-label')
        .attr('x', -innerHeight / 2)
        .attr('y', -margin.left + 15)
        .attr('transform', 'rotate(-90)')
        .style('text-anchor', 'middle')
        .text(yLabel);
    });
  };

  chart.width = (value) => {
    width = value;
    return chart;
  };

  chart.height = (value) => {
    height = value;
    return chart;
  };

  chart.margin = (value) => {
    margin = value;
    return chart;
  };

  chart.data = (value) => {
    data = value;
    return chart;
  };

  chart.xValue = (accessor) => {
    xValue = accessor;
    return chart;
  };

  chart.yValue = (accessor) => {
    yValue = accessor;
    return chart;
  };

  chart.zValue = (accessor) => {
    zValue = accessor;
    return chart;
  };

  chart.xLabel = (label) => {
    xLabel = label;
    return chart;
  };

  chart.yLabel = (label) => {
    yLabel = label;
    return chart;
  };

  chart.zLabel = (label) => {
    zLabel = label;
    return chart;
  };

  return chart;
};
